Learn R Programming

pcrcoal (version 1.2.0)

sample.tnt: Sample a coalescent tree according to a PCR experiment, return also subsample sizes and size trajectories

Description

This method returns a coalescent tree sampled according to the PCR experiment specified by the parameters stored in the slots of the PCRcoal object given as the first argument. All of the slots must contain a defined value.

This method also returns the subsample sizes and size trajectories corresponding to the sampled tree.

Usage

"sample.tnt"(object)

Arguments

object
A PCRcoal object, with all the slots defined.

Value

A list containing the following elements:

See Also

The PCRcoal class. The sample.tree and sample.trs methods.

Examples

Run this code
	# Construct a PCRcoal object 
	# and specify the experimental conditions:
	sim <-PCRcoal(
        initial.size    =5,
        sample.size     =10,
        nr.cycles       =30,
        efficiencies    =c(rep(0.1, 30))
    	)

	# Sample a coalescent tree with subsample sizes and
    # size trajectories:
	res <- sample.tnt(sim)

	# Print subsample sizes:
	print(res$subsamples)
	
	# Print size trajectories:
	print(res$trajectories)

	# Print tree info:
	print(res$phylo)

	# Plot the tree:
	plot(res$phylo)

Run the code above in your browser using DataLab